@@ -19,11 +19,11 @@ Audit::DBI - Audit data changes in your code and store searchable log records in
 
 =head1 VERSION
 
-Version 1.6.0
+Version 1.7.0
 
 =cut
 
-our $VERSION = '1.6.0';
+our $VERSION = '1.7.0';
 
 
 =head1 SYNOPSIS
@@ -456,6 +456,16 @@ the use of a separate reader database for example, to do expensive search
 queries. If this parameter is omitted, then the database handle specified when
 calling new() is used.
 
+=item * order_by
+
+An arrayref of fields and corresponding sort orders to use for sorting. By default,
+the audit events are sorted by ascending created date.
+
+	order_by =>
+	[
+		'created' => 'DESC',
+	]
+
 =back
 
 =cut
@@ -473,15 +483,43 @@ sub review ## no critic (Subroutines::ProhibitExcessComplexity)
 	my $logged_in = delete( $args{'logged_in'} );
 	my $affected = delete( $args{'affected'} );
 	
-	# Check remaining parameters.
+	# Retrieve non-search parameters.
 	my $dbh = delete( $args{'database_handle'} );
-	croak "Argument 'database_handle' must be a DBI object when defined"
-		if defined( $dbh ) && !Data::Validate::Type::is_instance( $dbh, class => 'DBI::db' );
+	$dbh = $self->get_database_handle()
+		if !defined( $dbh );
+	
+	my $order_by_array = delete( $args{'order_by'} );
+	$order_by_array = [ 'created', 'ASC' ]
+		if !defined( $order_by_array );
+	
+	# Check remaining parameters.
 	croak 'Invalid argument(s): ' . join( ', ', keys %args )
 		if scalar( keys %args ) != 0;
 	
 	### CLEAN PARAMETERS
 	
+	# Verify database handle argument.
+	croak "Argument 'database_handle' must be a DBI object when defined"
+		if defined( $dbh ) && !Data::Validate::Type::is_instance( $dbh, class => 'DBI::db' );
+	
+	# Verify order_by argument.
+	croak "Argument 'order_by' must be an arrayref when defined"
+		if !Data::Validate::Type::is_arrayref( $order_by_array );
+	croak "Argument 'order_by' must be a non-empty arrayref"
+		if scalar( @$order_by_array ) == 0;
+	croak "Argument 'order_by' must be an arrayref with an even number of elements"
+		if scalar( @$order_by_array ) % 2 == 1;
+	
+	my $order_by_array_copy = [ @$order_by_array ];
+	my $order_by_clauses = [];
+	while ( my ( $field, $sort_order) = splice( @$order_by_array_copy, 0, 2 ) )
+	{
+		croak "The sort order values for 'order_by' must be ASC or DESC"
+			if $sort_order !~ /^(?:ASC|DESC)$/i;
+		
+		push( @$order_by_clauses, $dbh->quote_identifier( $field ) . ' ' . uc( $sort_order ) );
+	}
+	
 	# Check that subjects are defined correctly.
 	if ( defined( $subjects ) )
 	{
@@ -561,8 +599,6 @@ sub review ## no critic (Subroutines::ProhibitExcessComplexity)
 	### PREPARE THE QUERY
 	my @clause = ();
 	my @join = ();
-	$dbh = $self->get_database_handle()
-		if !defined( $dbh );
 	
 	# Filter by IP range.
 	if ( defined( $ip_ranges ) )
@@ -698,15 +734,18 @@ sub review ## no critic (Subroutines::ProhibitExcessComplexity)
 		if scalar( @clause ) == 0;
 	
 	# Query the database.
-	my $joins = join( "\n", @join );
-	my $where = '(' . join( ') AND (', @clause ) . ')';
-	my $query = qq|
-		SELECT DISTINCT audit_events.*
-		FROM audit_events
-		$joins
-		WHERE $where
-		ORDER BY created ASC
-	|;
+	my $query = sprintf(
+		q|
+			SELECT DISTINCT audit_events.*
+			FROM audit_events
+			%s
+			WHERE %s
+			ORDER BY %s
+		|,
+		join( "\n", @join ),
+		'(' . join( ') AND (', @clause ) . ')',
+		join( ', ', @$order_by_clauses ),
+	);
 	
 	my $events_handle = $dbh->prepare( $query );
 	$events_handle->execute();
@@ -1175,8 +1214,8 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-audit-dbi at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Audit-DBI>.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/Audit-DBI/issues/new>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -1192,9 +1231,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Audit-DBI>
+L<https://github.com/guillaumeaubert/Audit-DBI/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -1226,7 +1265,7 @@ the stringification feature in v1.5.0.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012 Guillaume Aubert.
+Copyright 2010-2013 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
