@@ -17,11 +17,11 @@ Audit::DBI::TT2 - A Template Toolkit plugin to display audit events.
 
 =head1 VERSION
 
-Version 1.6.0
+Version 1.7.0
 
 =cut
 
-our $VERSION = '1.6.0';
+our $VERSION = '1.7.0';
 
 
 =head1 SYNOPSIS
@@ -141,8 +141,8 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-audit-dbi at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Audit-DBI>.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/Audit-DBI/issues/new>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -158,9 +158,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Audit-DBI>
+L<https://github.com/guillaumeaubert/Audit-DBI/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -186,7 +186,7 @@ for them!
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012 Guillaume Aubert.
+Copyright 2010-2013 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
